@@ -24,7 +24,7 @@ class MultiplexerChannelId:
     bytes: bytes = attr.ib(default=attr.Factory(lambda: os.urandom(16)), eq=True)
     hex: str = attr.ib(
         default=attr.Factory(
-            lambda self: binascii.hexlify(self.bytes).decode(), takes_self=True
+            lambda self: binascii.hexlify(self.bytes).decode("utf-8"), takes_self=True
         ),
         eq=False,
     )
